@@ -22,6 +22,9 @@ print.gbif <- function(x, ...) {
     if ("media" %in% names(x)) {
       cat(rgbif_wrap(sprintf("No. media records [%s]", length(x$media))), "\n")
     }
+    if("classifications" %in% names(x)) {
+      cat(rgbif_wrap(sprintf("No. classifications [%s]", length(x$classifications))), "\n")
+    }
     if ("facets" %in% names(x)) {
       cat(rgbif_wrap(sprintf("No. facets [%s]", length(x$facets))), "\n")
     }
@@ -113,4 +116,4 @@ print.gbif_data <- function(x, ..., n = 10) {
     attr(x, "return") <- NULL
     print(tibble::as_tibble(x))
   }
-}
+}
\ No newline at end of file
