@@ -5,7 +5,7 @@ test_that("name_backbone_checklist good data", {
   skip_on_ci()
   
   name_data <- data.frame(
-    name = c(
+    scientificName = c(
       NA, # missing value
       "Cirsium arvense (L.) Scop.", # a plant
       "Calopteryx splendens (Harris, 1780)", # an insect
@@ -54,30 +54,18 @@ test_that("name_backbone_checklist good data", {
       "Hymenochaete fuliginosa",
       "Aleurodiscus amorphus",
       "dog"
-    ), scientificName = c(
-      NA,
-      "Cirsium arvense (L.) Scop.", # a plant
-      "Calopteryx splendens (Harris, 1780)", # an insect
-      "Puma concolor (Linnaeus, 1771)", # a big cat
-      "Ceylonosticta alwisi (Priyadarshana & Wijewardhane, 2016)", # newly discovered insect 
-      "Puma concuolor (Linnaeus, 1771)", # a mis-spelled big cat
-      "Fake species (John Waller 2021)", # a fake species
-      "Calopteryx", # Just a Genus   
-      "Hymenochaete fuliginosa (Fr.) Lév.", # name with special character
-      "Aleurodiscus amorphus (Pers.) J. Schröt.", # name with special character
-      "dog [brackets break matching]"
     ))
 
-  # vcr does not seem to work with async requests  
+  # vcr does not work with async requests  
   # data.frame
   tt <- name_backbone_checklist(name_data = name_data)
   vv <- name_backbone_checklist(name_data = name_data,verbose=TRUE)
   # vector
-  ttt <- name_backbone_checklist(name_data = name_data$name) 
-  vvv <- name_backbone_checklist(name_data = name_data$name,verbose=TRUE)
+  ttt <- name_backbone_checklist(name_data = name_data$scientificName) 
+  vvv <- name_backbone_checklist(name_data = name_data$scientificName,verbose=TRUE)
   # one column
-  tttt <- name_backbone_checklist(name_data = name_data["name"]) 
-  vvvv <- name_backbone_checklist(name_data = name_data["name"],verbose=TRUE)
+  tttt <- name_backbone_checklist(name_data = name_data["scientificName"]) 
+  vvvv <- name_backbone_checklist(name_data = name_data["scientificName"],verbose=TRUE)
   # one column not aliased
   ttttt <- name_backbone_checklist(name_data = name_data["Canonical_Name"]) 
   vvvvv <- name_backbone_checklist(name_data = name_data["Canonical_Name"],verbose=TRUE)
@@ -89,95 +77,67 @@ test_that("name_backbone_checklist good data", {
   expect_is(tt, "tbl")
   expect_is(tt, "tbl_df")
   expect_is(tt, "data.frame")
-  expect_is(tt$usageKey, "integer")
   expect_is(tt$verbatim_name, "character")
   expect_equal(nrow(tt), 11)
   expect_true(all(tt$status == "ACCEPTED" | is.na(tt$status)))
-  expect_true(is.numeric(tt$verbatim_index))
-  expect_true(!is.unsorted(tt$verbatim_index))
-  
+
   expect_is(vv, "tbl")
   expect_is(vv, "tbl_df")
   expect_is(vv, "data.frame")
-  expect_is(vv$usageKey, "integer")
   expect_true(nrow(vv) > nrow(tt))
-  expect_true(is.numeric(vv$verbatim_index))
-  expect_true(!is.unsorted(vv$verbatim_index))
-  
+
   # vector
   expect_is(ttt, "tbl")
   expect_is(ttt, "tbl_df")
   expect_is(ttt, "data.frame")
-  expect_is(ttt$usageKey, "integer")
   expect_is(ttt$verbatim_name, "character")
   expect_equal(nrow(ttt), 11)
   expect_true(all(ttt$status == "ACCEPTED" | is.na(ttt$status)))
-  expect_true(is.numeric(ttt$verbatim_index))
-  expect_true(!is.unsorted(ttt$verbatim_index))
-  
+
   expect_is(vvv, "tbl")
   expect_is(vvv, "tbl_df")
   expect_is(vvv, "data.frame")
-  expect_is(vvv$usageKey, "integer")
   expect_true(nrow(vvv) > nrow(ttt))
-  expect_true(is.numeric(vvv$verbatim_index))
-  expect_true(!is.unsorted(vvv$verbatim_index))
-  
+
   # one column data.frame
   expect_is(tttt, "tbl")
   expect_is(tttt, "tbl_df")
   expect_is(tttt, "data.frame")
-  expect_is(tttt$usageKey, "integer")
   expect_is(tttt$verbatim_name, "character")
   expect_equal(nrow(tttt), 11)
   expect_true(all(tttt$status == "ACCEPTED" | is.na(tttt$status)))
-  expect_true(is.numeric(tttt$verbatim_index))
-  expect_true(!is.unsorted(tttt$verbatim_index))
 
   expect_is(vvvv, "tbl")
   expect_is(vvvv, "tbl_df")
   expect_is(vvvv, "data.frame")
-  expect_is(vvvv$usageKey, "integer")
   expect_true(nrow(vvvv) > nrow(tttt))
   
   # one column that is not an alias 
   expect_is(ttttt, "tbl")
   expect_is(ttttt, "tbl_df")
   expect_is(ttttt, "data.frame")
-  expect_is(ttttt$usageKey, "integer")
   expect_is(ttttt$verbatim_name, "character")
   expect_equal(nrow(ttttt), 11)
   expect_true(all(ttttt$status == "ACCEPTED" | is.na(ttttt$status)))
-  expect_true(is.numeric(ttttt$verbatim_index))
-  expect_true(!is.unsorted(ttttt$verbatim_index))
-  
+
   expect_is(vvvvv, "tbl")
   expect_is(vvvvv, "tbl_df")
   expect_is(vvvvv, "data.frame")
-  expect_is(vvvvv$usageKey, "integer")
   expect_true(nrow(vvvvv) > nrow(ttttt))
-  expect_true(is.numeric(vvvvv$verbatim_index))
-  expect_true(!is.unsorted(vvvvv$verbatim_index))
-  
+
   # aliased name multiple columns
   expect_is(tttttt, "tbl")
   expect_is(tttttt, "tbl_df")
   expect_is(tttttt, "data.frame")
-  expect_is(tttttt$usageKey, "integer")
   expect_is(tttttt$verbatim_name, "character")
   expect_equal(nrow(tttttt), 11)
   expect_true(all(tttttt$status == "ACCEPTED" | is.na(tttttt$status)))
-  expect_true(is.numeric(tttttt$verbatim_index))
-  expect_true(!is.unsorted(tttttt$verbatim_index))
-  
+
   expect_is(vvvvvv, "tbl")
   expect_is(vvvvvv, "tbl_df")
   expect_is(vvvvvv, "data.frame")
-  expect_is(vvvvvv$usageKey, "integer")
   expect_true(nrow(vvvvvv) > nrow(tttttt))
-  expect_true(is.numeric(vvvvvv$verbatim_index))
-  expect_true(!is.unsorted(vvvvvv$verbatim_index))
-  
+
   })
   
 test_that("name_backbone_checklist bad or weird data", {
@@ -236,20 +196,11 @@ test_that("name_backbone_checklist bad or weird data", {
   # bad data 
   expect_error(name_backbone_checklist(name_data = NULL),"You forgot to supply your checklist data.frame or vector to name_data.")
   expect_error(name_backbone_checklist(name_data = 1),"name_data should be class character.")
-  expect_error(name_backbone_checklist(name_data = data.frame(1)),"The name column should be class character.")
-  
-  # name column is a factor
-  name_data_factor = name_data
-  name_data_factor$name<-as.factor(name_data_factor$name)
-  expect_error(name_backbone_checklist(name_data = name_data_factor),"All taxonomic columns should be character.")
-  name_data_factor$name<-as.numeric(name_data_factor$name)
-  expect_error(name_backbone_checklist(name_data = name_data_factor),"All taxonomic columns should be character.")
+  expect_error(name_backbone_checklist(name_data = data.frame(1)),"The scientificName column should be class character.")
   
   # just missing names
   ff <- name_backbone_checklist(name_data = c("fake name 1","fake name 2"))
   zz <- name_backbone_checklist(name_data = c("fake name 1","fake name 2"),verbose=TRUE)
-  expect_equal(colnames(ff), c("confidence","matchType", "synonym", "verbatim_name","verbatim_index"))
-  expect_equal(colnames(zz), c("confidence","matchType", "synonym", "is_alternative", "verbatim_name","verbatim_index"))
   expect_true(nrow(ff) == nrow(zz))
   expect_equal(unique(ff$matchType), "NONE")
   expect_equal(unique(zz$matchType), "NONE")
@@ -259,8 +210,8 @@ test_that("name_backbone_checklist bad or weird data", {
   # just one missing name
   fff <- name_backbone_checklist(name_data = name_data[1,])
   zzz <- name_backbone_checklist(name_data = name_data[1,],verbose=TRUE)   
-  expect_equal(colnames(fff), c("confidence","matchType", "synonym", "verbatim_name", "verbatim_kingdom","verbatim_index"))
-  expect_equal(colnames(zzz), c("confidence","matchType", "synonym", "is_alternative", "verbatim_name","verbatim_kingdom","verbatim_index"))
+  # expect_equal(colnames(fff), c("confidence","matchType", "synonym", "verbatim_name", "verbatim_kingdom","verbatim_index"))
+  # expect_equal(colnames(zzz), c("confidence","matchType", "synonym", "is_alternative", "verbatim_name","verbatim_kingdom","verbatim_index"))
   expect_true(nrow(fff) == nrow(zzz))
   expect_equal(unique(fff$matchType), "NONE")
   expect_equal(unique(zzz$matchType), "NONE")
@@ -270,101 +221,6 @@ test_that("name_backbone_checklist bad or weird data", {
   })
 
 # strict arg might not work until switch to v2
-# test_that("name_backbone_checklist strict arg works as expected", {
-#   skip_on_cran()
-#   skip_on_ci()
-#   
-#   name_data <- data.frame(
-#     name = c(
-#       NA, # missing value
-#       "Cirsium arvense (L.) Scop.", # a plant
-#       "Calopteryx splendens (Harris, 1780)", # an insect
-#       "Puma concolor (Linnaeus, 1771)", # a big cat
-#       "Ceylonosticta alwisi (Priyadarshana & Wijewardhane, 2016)", # newly discovered insect 
-#       "Puma concuolor (Linnaeus, 1771)", # a mis-spelled big cat
-#       "Fake species (John Waller 2021)", # a fake species
-#       "Calopteryx", # Just a Genus
-#       "Calopteryx fake" # make higher rank match
-#     ), description = c(
-#       "missing",
-#       "a plant",
-#       "an insect",
-#       "a big cat",
-#       "newly discovered insect",
-#       "a mis-spelled big cat",
-#       "a fake species",
-#       "just a GENUS",
-#       "higherrank match"
-#     ), 
-#     kingdom = c(
-#       "missing",
-#       "Plantae",
-#       "Animalia",
-#       "Animalia",
-#       "Animalia",
-#       "Animalia",
-#       "Johnlia",
-#       "Animalia",
-#       "Animalia"
-#     ), Canonical_Name = c(
-#       "not known",
-#       "Cirsium arvense", 
-#       "Calopteryx splendens", 
-#       "Puma concolor", 
-#       "Ceylonosticta alwisi", 
-#       "Puma concuolor", 
-#       "Fake species",
-#       "Calopteryx",
-#       "Calopteryx fake"
-#     ), scientificName = c(
-#       NA,
-#       "Cirsium arvense (L.) Scop.", # a plant
-#       "Calopteryx splendens (Harris, 1780)", # an insect
-#       "Puma concolor (Linnaeus, 1771)", # a big cat
-#       "Ceylonosticta alwisi (Priyadarshana & Wijewardhane, 2016)", # newly discovered insect 
-#       "Puma concuolor (Linnaeus, 1771)", # a mis-spelled big cat
-#       "Fake species (John Waller 2021)", # a fake species
-#       "Calopteryx", # Just a Genus
-#       "Calopteryx fake Waller 2022"
-#     ))
-#   
-#     ff <- name_backbone_checklist(name_data)
-#     # these tests fail need to switch to v2 
-#     # ss <- name_backbone_checklist(name_data,strict=TRUE)
-#     # sv <- name_backbone_checklist(name_data,verbose=TRUE,strict=TRUE)
-#     
-#     # basic functionality 
-#     expect_is(ss, "tbl")
-#     expect_is(ss, "tbl_df")
-#     expect_is(ss, "data.frame")
-#     expect_true(is.numeric(ss$verbatim_index))
-#     expect_true(!is.unsorted(ss$verbatim_index))
-#     
-#     # basic functionality 
-#     expect_is(sv, "tbl")
-#     expect_is(sv, "tbl_df")
-#     expect_is(sv, "data.frame")
-#     expect_true(is.numeric(sv$verbatim_index))
-#     expect_true(!is.unsorted(sv$verbatim_index))
-#     
-#     # correct matchType is returned 
-#     expect_true(all(ff$matchType %in% c("NONE","EXACT","FUZZY","HIGHERRANK")))
-#     
-#     expect_true(all(ss$matchType %in% c("NONE","EXACT")))
-#     expect_false(all(ss$matchType %in% c("FUZZY","HIGHERRANK")))
-#     
-#     expect_true(all(sv$matchType %in% c("NONE","EXACT")))
-#     expect_false(all(sv$matchType %in% c("FUZZY","HIGHERRANK")))
-#     
-#     # More matchType NONE is returned for strict
-#     expect_true(nrow(ff[ff$matchType == "NONE",]) < nrow(ss[ss$matchType == "NONE",]))
-#     
-#     # More rows for verbose=true and strict=true
-#     expect_true(nrow(sv) > nrow(ss))
-#     expect_true(nrow(sv) > nrow(ff))
-#     
-#     
-# })
 
 test_that("name_backbone_checklist default values works as expected", {
   skip_on_cran()
@@ -381,8 +237,6 @@ test_that("name_backbone_checklist default values works as expected", {
   expect_is(dd, "tbl")
   expect_is(dd, "tbl_df")
   expect_is(dd, "data.frame")
-  expect_true(is.numeric(dd$verbatim_index))
-  expect_true(!is.unsorted(dd$verbatim_index))
   expect_true(all(dd$verbatim_kingdom == "Animalia"))
   
   rr <- name_backbone_checklist(c("Cirsium arvense (L.) Scop.", 
@@ -459,21 +313,21 @@ test_that("name_backbone_checklist default values works as expected", {
     expect_is(oo, "tbl")
     expect_is(oo, "tbl_df")
     expect_is(oo, "data.frame")
-    expect_true(is.numeric(oo$verbatim_index))
-    expect_true(!is.unsorted(oo$verbatim_index))
     expect_true(all(oo$verbatim_kingdom == "Animalia"))
 })
 
 test_that("name_backbone_checklist is_alternative works as expected", {
   skip_on_cran()
   skip_on_ci()
-  
+
   ff <- name_backbone_checklist("Calopteryx",verbose=FALSE)
-  expect_warning(ff$is_alternative, "Unknown or uninitialised column: `is_alternative`.")
   aa <- name_backbone_checklist("Calopteryx",verbose=TRUE)
+  
+  expect_false(any(is.na(ff$is_alternative)))
+  expect_true(is.logical(ff$is_alternative))
   expect_true(is.logical(aa$is_alternative))
   expect_false(any(is.na(aa$is_alternative)))
-  
+
 })
 
 test_that("name_backbone_checklist returns the same as name_backbone", {
@@ -487,6 +341,42 @@ test_that("name_backbone_checklist returns the same as name_backbone", {
   
 })
 
+test_that("name_backbone_checklist works with v2 args", {
+  skip_on_cran()
+  skip_on_ci()
+  
+  cc <- name_backbone_checklist(name_data = 
+                      c("Aves","Calopteryx splendens", "Animalia"),
+                      checklistKey="7ddf754f-d193-4cc9-b351-99906754a03b")
+  
+  
+  bb <- name_backbone_checklist(name_data =  
+  data.frame(scientificName = 
+               c("Aves","Calopteryx splendens", "Animalia"),
+             checklistKey="7ddf754f-d193-4cc9-b351-99906754a03b"))
+  
+  
+  expect_is(cc, "tbl")
+  expect_is(cc, "tbl_df")
+  expect_is(cc, "data.frame")
+  expect_equal(nrow(cc), 3)
+  expect_equal(cc$matchType, c("HIGHERRANK", "EXACT", "HIGHERRANK"))
+  expect_equal(cc$verbatim_name, 
+               c("Aves", "Calopteryx splendens", "Animalia"))
+  expect_equal(cc$kingdom, c("Animalia", "Animalia", "Animalia"))
+  expect_equal(cc$rank, c("CLASS", "SPECIES", "KINGDOM"))
+  
+  expect_is(bb, "tbl")
+  expect_is(bb, "tbl_df")
+  expect_is(bb, "data.frame")
+  expect_equal(nrow(bb), 3)
+  expect_equal(cc$matchType, bb$matchType)
+  expect_equal(cc$verbatim_name, bb$verbatim_name)
+  expect_equal(cc$kingdom, bb$kingdom)
+  expect_equal(cc$rank, bb$rank)
+  expect_equal(cc$usageKey, bb$usageKey)
+  
+})
 
 
 # test_that("test status codes", {
@@ -507,8 +397,29 @@ test_that("name_backbone_checklist returns the same as name_backbone", {
 #   
 # })
 
+test_that("name_backbone_checklist bucket_size and sleep ", {
+  skip_on_cran()
+  skip_on_ci()
 
+  names <- name_lookup(limit=100)$data$canonicalName
+  start <- proc.time()
+  ss <- name_backbone_checklist(name_data = names,
+                                bucket_size = 10,
+                                sleep = 10)  
+  end <- proc.time()
+  time1 <- end - start
 
+  start <- proc.time()
+  mm <- name_backbone_checklist(name_data = names,
+                                bucket_size = 10,
+                                sleep = 1)  
+  end <- proc.time()
+  time2 <- end - start
 
+  expect_equal(nrow(ss), nrow(mm))
+  expect_is(ss, "data.frame")
+  expect_is(mm, "data.frame")
+  expect_true(time1['elapsed'] > time2['elapsed'] )
 
+})
 
