@@ -21,10 +21,10 @@ test_that("returns the correct class", {
   expect_is(h, "character")
 
   # returns the correct value
-  expect_equal(a[[1]], "122")
-  expect_equal(b[[1]], "12")
-  expect_equal(tolower(d[[1]]), "gb")
-  expect_true(grepl("scott", h[[1]]))
+  expect_match(a[[1]], "122")
+  expect_match(b[[1]], "12")
+  expect_match(tolower(d[[1]]), "gb")
+  expect_true(grepl("scott", h[[1]], ignore.case = TRUE))
 
   # returns the correct dimensions
   expect_equal(length(a), 5)
